@@ -128,7 +128,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
         return false;
     };
     const addressIpv4Helper = (address) => {
-        const config = { address, netmask: null, gateway: null };
+        const config = { address, netmask: '', gateway: '' };
         const split = address.split('.');
 
         if (split.length !== 4)
@@ -141,7 +141,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
             return { ...config, netmask: "255.255.0.0" };
         } else if (split[0] <= 192 && split[0] <= 223) {
             return { ...config, netmask: "255.255.255.0" };
-        } else return { ...config, gateway: null };
+        } else return { ...config, gateway: '' };
     };
 
     return (
@@ -161,7 +161,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                                 <FormSelect className="network-ip-settings-method"
                                             id={idPrefix + "-select-method"}
                                             aria-label={_("Select method")}
-                                            onChange={setMethod}
+                                            onChange={(_, val) => setMethod(val)}
                                             value={method}>
                                     {(topic == "ipv4" ? ipv4_method_choices : ipv6_method_choices).map(choice => <FormSelectOption value={choice.choice} label={choice.title} key={choice.choice} />)}
                                 </FormSelect>
@@ -182,7 +182,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                     return (
                         <Grid key={i} hasGutter>
                             <FormGroup fieldId={idPrefix + "-address-" + i} label={_("Address")} className="pf-m-4-col-on-sm">
-                                <TextInput id={idPrefix + "-address-" + i} value={address.address} onChange={value => setAddresses(
+                                <TextInput id={idPrefix + "-address-" + i} value={address.address} onChange={(_event, value) => setAddresses(
                                     addresses.map((item, index) =>
                                         i === index
                                             ? addressIpv4Helper(value)
@@ -190,7 +190,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                                     ))} />
                             </FormGroup>
                             <FormGroup fieldId={idPrefix + "-netmask-" + i} label={prefixText} className="pf-m-4-col-on-sm">
-                                <TextInput id={idPrefix + "-netmask-" + i} value={address.netmask} onChange={value => setAddresses(
+                                <TextInput id={idPrefix + "-netmask-" + i} value={address.netmask} onChange={(_event, value) => setAddresses(
                                     addresses.map((item, index) =>
                                         i === index
                                             ? { ...item, netmask: value }
@@ -198,7 +198,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                                     ))} />
                             </FormGroup>
                             <FormGroup fieldId={idPrefix + "-gateway-" + i} label={_("Gateway")} className="pf-m-4-col-on-sm">
-                                <TextInput id={idPrefix + "-gateway-" + i} value={address.gateway} onChange={value => setAddresses(
+                                <TextInput id={idPrefix + "-gateway-" + i} value={address.gateway} onChange={(_event, value) => setAddresses(
                                     addresses.map((item, index) =>
                                         i === index
                                             ? { ...item, gateway: value }
@@ -226,7 +226,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                                 <Switch
                                     isChecked={!ignoreAutoDns}
                                     isDisabled={!canAuto}
-                                    onChange={value => setIgnoreAutoDns(!value)}
+                                    onChange={(_event, value) => setIgnoreAutoDns(!value)}
                                     label={_("Automatic")} />
                                 <Button variant="secondary"
                                         isDisabled={!canHaveExtra}
@@ -243,7 +243,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                     return (
                         <Grid key={i} hasGutter>
                             <FormGroup fieldId={idPrefix + "-dns-server-" + i} label={_("Server")}>
-                                <TextInput id={idPrefix + "-dns-server-" + i} value={server} onChange={value => setDns(
+                                <TextInput id={idPrefix + "-dns-server-" + i} value={server} onChange={(_event, value) => setDns(
                                     dns.map((item, index) =>
                                         i === index
                                             ? value
@@ -252,7 +252,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                             </FormGroup>
                             <FormGroup className="pf-m-1-col-on-sm remove-button-group">
                                 <Button variant='secondary'
-                                        isSmall
+                                        size="sm"
                                         onClick={() => setDns(dns.filter((_, index) => index !== i))}
                                         aria-label={_("Remove item")}
                                         icon={<MinusIcon />} />
@@ -271,7 +271,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                                 <Switch
                                     isChecked={!ignoreAutoDns}
                                     isDisabled={!canAuto}
-                                    onChange={value => setIgnoreAutoDns(!value)}
+                                    onChange={(_event, value) => setIgnoreAutoDns(!value)}
                                     label={_("Automatic")} />
                                 <Button variant="secondary"
                                         isDisabled={!canHaveExtra}
@@ -288,7 +288,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                     return (
                         <Grid key={i} hasGutter>
                             <FormGroup fieldId={idPrefix + "-search-domain-" + i} label={_("Search domain")}>
-                                <TextInput id={idPrefix + "-search-domain-" + i} value={domain} onChange={value => setDnsSearch(
+                                <TextInput id={idPrefix + "-search-domain-" + i} value={domain} onChange={(_event, value) => setDnsSearch(
                                     dnsSearch.map((item, index) =>
                                         i === index
                                             ? value
@@ -297,7 +297,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                             </FormGroup>
                             <FormGroup className="pf-m-1-col-on-sm remove-button-group">
                                 <Button variant='secondary'
-                                        isSmall
+                                        size="sm"
                                         onClick={() => setDnsSearch(dnsSearch.filter((_, index) => index !== i))}
                                         aria-label={_("Remove item")}
                                         icon={<MinusIcon />} />
@@ -316,7 +316,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                                 <Switch
                                     isChecked={!ignoreAutoRoutes}
                                     isDisabled={!canAuto}
-                                    onChange={value => setIgnoreAutoRoutes(!value)}
+                                    onChange={(_event, value) => setIgnoreAutoRoutes(!value)}
                                     label={_("Automatic")} />
                                 <Button variant="secondary"
                                         isDisabled={isOff}
@@ -333,7 +333,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                     return (
                         <Grid key={i} hasGutter>
                             <FormGroup fieldId={idPrefix + "-route-address-" + i} label={_("Address")} className="pf-m-3-col-on-sm">
-                                <TextInput id={idPrefix + "-route-address-" + i} value={route.address} onChange={value => setRoutes(
+                                <TextInput id={idPrefix + "-route-address-" + i} value={route.address} onChange={(_event, value) => setRoutes(
                                     routes.map((item, index) =>
                                         i === index
                                             ? { ...item, address: value }
@@ -341,7 +341,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                                     ))} />
                             </FormGroup>
                             <FormGroup fieldId={idPrefix + "-route-netmask-" + i} label={_("Prefix length or netmask")} className="pf-m-4-col-on-sm">
-                                <TextInput id={idPrefix + "-route-netmask-" + i} value={route.netmask} onChange={value => setRoutes(
+                                <TextInput id={idPrefix + "-route-netmask-" + i} value={route.netmask} onChange={(_event, value) => setRoutes(
                                     routes.map((item, index) =>
                                         i === index
                                             ? { ...item, netmask: value }
@@ -349,7 +349,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                                     ))} />
                             </FormGroup>
                             <FormGroup fieldId={idPrefix + "-route-gateway-" + i} label={_("Gateway")} className="pf-m-3-col-on-sm">
-                                <TextInput id={idPrefix + "-route-gateway-" + i} value={route.gateway} onChange={value => setRoutes(
+                                <TextInput id={idPrefix + "-route-gateway-" + i} value={route.gateway} onChange={(_event, value) => setRoutes(
                                     routes.map((item, index) =>
                                         i === index
                                             ? { ...item, gateway: value }
@@ -357,7 +357,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                                     ))} />
                             </FormGroup>
                             <FormGroup fieldId={idPrefix + "-route-metric-" + i} label={_("Metric")} className="pf-m-2-col-on-sm">
-                                <TextInput id={idPrefix + "-route-metric-" + i} value={route.metric} onChange={value => setRoutes(
+                                <TextInput id={idPrefix + "-route-metric-" + i} value={route.metric} onChange={(_event, value) => setRoutes(
                                     routes.map((item, index) =>
                                         i === index
                                             ? { ...item, metric: value }
@@ -366,7 +366,7 @@ export const IpSettingsDialog = ({ topic, connection, dev, settings }) => {
                             </FormGroup>
                             <FormGroup className="pf-m-1-col-on-sm remove-button-group">
                                 <Button variant='secondary'
-                                        isSmall
+                                        size="sm"
                                         onClick={() => setRoutes(routes.filter((_, index) => index !== i))}
                                         aria-label={_("Remove item")}
                                         icon={<MinusIcon />} />
