@@ -20,11 +20,11 @@ import cockpit from "cockpit";
 import React, { useContext } from "react";
 import { Breadcrumb, BreadcrumbItem } from "@patternfly/react-core/dist/esm/components/Breadcrumb/index.js";
 import { Button } from "@patternfly/react-core/dist/esm/components/Button/index.js";
-import { Card, CardActions, CardBody, CardHeader, CardTitle } from "@patternfly/react-core/dist/esm/components/Card/index.js";
+import { Card, CardBody, CardHeader, CardTitle } from '@patternfly/react-core/dist/esm/components/Card/index.js';
 import { Checkbox } from "@patternfly/react-core/dist/esm/components/Checkbox/index.js";
 import { DescriptionList, DescriptionListDescription, DescriptionListGroup, DescriptionListTerm } from "@patternfly/react-core/dist/esm/components/DescriptionList/index.js";
 import { Gallery } from "@patternfly/react-core/dist/esm/layouts/Gallery/index.js";
-import { Page, PageSection, PageSectionVariants } from "@patternfly/react-core/dist/esm/components/Page/index.js";
+import { Page, PageBreadcrumb, PageSection, PageSectionVariants } from "@patternfly/react-core/dist/esm/components/Page/index.js";
 import { Switch } from "@patternfly/react-core/dist/esm/components/Switch/index.js";
 
 import { ModelContext } from './model-context.jsx';
@@ -130,9 +130,9 @@ export const NetworkInterfacePage = ({
 
         function modify() {
             if (iface.MainConnection) {
-                return iface.MainConnection.activate(dev, null).fail(fail);
+                return iface.MainConnection.activate(dev, null).catch(fail);
             } else {
-                return dev.activate_with_settings(ghostSettings, null).fail(fail);
+                return dev.activate_with_settings(ghostSettings, null).catch(fail);
             }
         }
 
@@ -152,9 +152,7 @@ export const NetworkInterfacePage = ({
 
         function modify () {
             return dev.disconnect()
-                    .fail(function (error) {
-                        show_unexpected_error(error);
-                    });
+                    .catch(error => show_unexpected_error(error));
         }
 
         with_checkpoint(model, modify,
@@ -264,7 +262,7 @@ export const NetworkInterfacePage = ({
         return (
             <DescriptionListGroup>
                 <DescriptionListTerm>{_("Status")}</DescriptionListTerm>
-                <DescriptionListDescription>
+                <DescriptionListDescription className="networking-interface-status">
                     {activeConnection}
                     {state ? <span>{state}</span> : null}
                 </DescriptionListDescription>
@@ -328,7 +326,7 @@ export const NetworkInterfacePage = ({
                         <DescriptionListTerm>{_("General")}</DescriptionListTerm>
                         <DescriptionListDescription>
                             <Checkbox id="autoreconnect" isDisabled={!privileged}
-                                      onChange={checked => {
+                                      onChange={(_event, checked) => {
                                           settings.connection.autoconnect = checked;
                                           settings_applier(self.model, dev, con)(settings);
                                       }}
@@ -675,7 +673,7 @@ export const NetworkInterfacePage = ({
         onoff = (
             <Switch isChecked={!!(dev && dev.ActiveConnection)}
                     isDisabled={!iface || (dev && dev.State == 20)}
-                    onChange={enable => enable ? connect() : disconnect()}
+                    onChange={(_event, enable) => enable ? connect() : disconnect()}
                     aria-label={_("Enable or disable the device")} />
         );
     }
@@ -689,40 +687,43 @@ export const NetworkInterfacePage = ({
             .map((component, idx) => <React.Fragment key={idx}>{component}</React.Fragment>);
 
     return (
-        <Page groupProps={{ sticky: 'top' }}
-              isBreadcrumbGrouped
-              id="network-interface"
-              data-test-wait={operationInProgress}
-              breadcrumb={
-                  <Breadcrumb>
-                      <BreadcrumbItem to='#/'>
-                          {_("Networking")}
-                      </BreadcrumbItem>
-                      <BreadcrumbItem isActive>
-                          {dev_name}
-                      </BreadcrumbItem>
-                  </Breadcrumb>}>
+        <Page id="network-interface"
+              data-test-wait={operationInProgress}>
+            <PageBreadcrumb stickyOnBreakpoint={{ default: "top" }}>
+                <Breadcrumb>
+                    <BreadcrumbItem to='#/'>
+                        {_("Networking")}
+                    </BreadcrumbItem>
+                    <BreadcrumbItem isActive>
+                        {dev_name}
+                    </BreadcrumbItem>
+                </Breadcrumb>
+            </PageBreadcrumb>
             <PageSection variant={PageSectionVariants.light}>
                 <NetworkPlots plot_state={plot_state} />
             </PageSection>
             <PageSection>
                 <Gallery hasGutter>
                     <Card className="network-interface-details">
-                        <CardHeader>
+                        <CardHeader actions={{
+                            actions: (
+                                <>
+                                    {isDeletable && isManaged &&
+                                    <Button variant="danger"
+                                                 onClick={syn_click(model, deleteConnections)}
+                                                 id="network-interface-delete">
+                                        {_("Delete")}
+                                    </Button>}
+                                    {onoff}
+                                </>
+                            ),
+                        }}>
                             <CardTitle className="network-interface-details-title">
                                 <span id="network-interface-name">{dev_name}</span>
                                 <span id="network-interface-hw">{renderDesc()}</span>
                                 <span id="network-interface-mac">{renderMac()}</span>
                             </CardTitle>
-                            <CardActions>
-                                {isDeletable && isManaged &&
-                                <Button variant="danger"
-                                         onClick={syn_click(model, deleteConnections)}
-                                         id="network-interface-delete">
-                                    {_("Delete")}
-                                </Button>}
-                                {onoff}
-                            </CardActions>
+
                         </CardHeader>
                         <CardBody>
                             <DescriptionList id="network-interface-settings" className="network-interface-settings pf-m-horizontal-on-sm">
