@@ -115,7 +115,7 @@ const UnlockDialog = ({ proxy, host }) => {
     }
 
     function init() {
-        return proxy.Stop().always(() => {
+        return proxy.Stop().finally(() => {
             if (proxy.Methods) {
                 const ids = Object.keys(proxy.Methods);
                 if (ids.length == 0)
@@ -203,7 +203,7 @@ const UnlockDialog = ({ proxy, host }) => {
             <Form isHorizontal>
                 <FormGroup fieldId="switch-to-admin-access-bridge-select"
                            label={_("Method")}>
-                    <FormSelect value={method} onChange={(_, method) => setMethod(method)} isDisabled={busy}>
+                    <FormSelect id="switch-to-admin-access-bridge-select" value={method} onChange={(_, method) => setMethod(method)} isDisabled={busy}>
                         { methods.map(m => <FormSelectOption value={m} key={m}
                                                              label={_(proxy.Methods[m].v.label.v)} />) }
                     </FormSelect>
@@ -300,7 +300,11 @@ const SuperuserDialogs = ({ superuser_proxy, host, create_trigger }) => {
                  }
              });
 
-    const show = superuser_proxy.Current != "root" && superuser_proxy.Current != "init";
+    if (!superuser_proxy || !superuser_proxy.valid)
+        return;
+
+    const show = (superuser_proxy.Current != "root" && superuser_proxy.Current != "init" &&
+                  superuser_proxy.Bridges.length > 0);
     const unlocked = superuser_proxy.Current != "none";
 
     function unlock() {
@@ -311,7 +315,7 @@ const SuperuserDialogs = ({ superuser_proxy, host, create_trigger }) => {
         D.show(<LockDialog proxy={superuser_proxy} host={host} />);
     }
 
-    if (!show || !superuser_proxy.Bridges || superuser_proxy.Bridges.length == 0)
+    if (!show)
         return null;
 
     return create_trigger(unlocked, unlocked ? lock : unlock);
